
; FASM SOURCE FILE
; http://flatassembler.net

; B2C2

; written by @L.CHEMIST (Andrey A. Meshkov)
; maalchemist@gmail.com
; maa-mail@yandex.ru

; ------------------------------------------------------------------------------

; FEC enumeration used by SetFEC()/GetFEC()
TYPEDEF TB2C2_FEC, enum

FEC_1_2   = 1
FEC_2_3   = 2
FEC_3_4   = 3
FEC_5_6   = 4
FEC_7_8   = 5
FEC_AUTO  = 6
FEC_COUNT = 6

; ------------------------------------------------------------------------------

; Guard interval enumeration used by SetGuardInterval()/GetGuardInterval()
TYPEDEF TB2C2_GuardInterval, enum

GUARD_INTERVAL_1_32  = 0
GUARD_INTERVAL_1_16  = 1
GUARD_INTERVAL_1_8   = 2
GUARD_INTERVAL_1_4   = 3
GUARD_INTERVAL_AUTO  = 4
GUARD_INTERVAL_COUNT = 5

; ------------------------------------------------------------------------------

; Bandwidth enumeration used by SetBandwidth()/GetBandwidth()
TYPEDEF TB2C2_BandWidth, enum

BANDWIDTH_6_MHZ   = 6
BANDWIDTH_7_MHZ   = 7
BANDWIDTH_8_MHZ   = 8
BANDWIDTH_COUNT   = 3
BANDWIDTH_UNKNOWN = -1

; ------------------------------------------------------------------------------

; Polarity enumeration used by SetPolarity()/GetPolarity ()
TYPEDEF TB2C2_Polarity, enum

POLARITY_HORIZONTAL   = 0
POLARITY_VERTICAL     = 1
POLARITY_COUNT        = 2
; if no LNB power is needed
POLARITY_LNB_NO_POWER = 10

; ------------------------------------------------------------------------------

; LNB enumeration used by SetLnbKHz()/GetLnbKHz()
TYPEDEF TB2C2_LNBSelection, enum

LNB_SELECTION_0     = 0
LNB_SELECTION_22    = 1
LNB_SELECTION_33    = 2
LNB_SELECTION_44    = 3
LNB_SELECTION_COUNT = 4

; ------------------------------------------------------------------------------

; Diseqc enumeration used by SetDiseqc()/GetDiseqc()
TYPEDEF TB2C2_Diseqc, enum

DISEQC_NONE        = 0
DISEQC_SIMPLE_A    = 1
DISEQC_SIMPLE_B    = 2
DISEQC_LEVEL_1_A_A = 3
DISEQC_LEVEL_1_B_A = 4
DISEQC_LEVEL_1_A_B = 5
DISEQC_LEVEL_1_B_B = 6
DISEQC_COUNT       = 7

; ------------------------------------------------------------------------------

; Modulation enumeration used by SetModulation()/GetModulation()
TYPEDEF TB2C2_Modulation, enum

QAM_4           = 2
QAM_16          = 3
QAM_32          = 4
QAM_64          = 5
QAM_128         = 6
QAM_256         = 7
QAM_64_ANNEX_B  = 8
QAM_256_ANNEX_B = 9
VSB_8           = 10
VSB_16          = 11
MODE_UNKNOWN    = -1

; ------------------------------------------------------------------------------

; Tuner Modulation enumeration used in TunerCapabilities structure to
; return the modulation used by the tuner.
TYPEDEF TB2C2_TunerModulation, enum

TUNER_SATELLITE        = 0
TUNER_CABLE            = 1
TUNER_TERRESTRIAL      = 2
TUNER_ATSC             = 3
TUNER_TERRESTRIAL_DVB  = TUNER_TERRESTRIAL
TUNER_TERRESTRIAL_ATSC = TUNER_ATSC
TUNER_UNKNOWN          = -1

; ------------------------------------------------------------------------------

; Structure completedy by GetTunerCapabilities() to return tuner capabilities
struct TB2C2_TunerCapabilities
  eModulation                   TB2C2_TunerModulation ?
  dwConstellationSupported      DWORD ?
  dwFECSupported                DWORD ?
  dwMinTransponderFreqInKHz     DWORD ?
  dwMaxTransponderFreqInKHz     DWORD ?
  dwMinTunerFreqInKHz           DWORD ?
  dwMaxTunerFreqInKHz           DWORD ?
  dwMinSymbolRateInBaud         DWORD ?
  dwMaxSymbolRateInBaud         DWORD ?
  bAutoSymbolRate               DWORD ?
  dwPerformanceMonitoring       DWORD ?
  dwLockTimeInMilliSecond       DWORD ?
  dwKernelLockTimeInMilliSecond DWORD ?
  dwAcquisitionCapabilities     DWORD ?
ends
TYPEDEF PB2C2_TunerCapabilities, POINTER

; ------------------------------------------------------------------------------

; Bitmasks for comparison with dwPerformanceMonitoring member of tTunerCapabilities
; to determine which of these various options are supported by the current tuner.
; If set in dwPerformanceMonitoring, tuner supports:
BER_SUPPORTED                     = 1 shl 0 ; // BER reporting via GetPreErrorCorrectionBER ()
BLOCK_COUNT_SUPPORTED             = 1 shl 1 ; // Block count report via GetTotalBlocks ()
CORRECTED_BLOCK_COUNT_SUPPORTED   = 1 shl 2 ; // Corrected block count via GetCorrectedBlocks
UNCORRECTED_BLOCK_COUNT_SUPPORTED = 1 shl 3 ; // Uncorrected block count via GetUncorrectedBlocks
SNR_SUPPORTED                     = 1 shl 4 ; // SNR via GetSNR ()
SIGNAL_STRENGTH_SUPPORTED         = 1 shl 5 ; // Signal strength via GetSignalStrength()
SIGNAL_QUALITY_SUPPORTED          = 1 shl 6 ; // Signal quality via GetSignalQuality()

; ------------------------------------------------------------------------------

; **** Acquisition Capabilities flags. ****
ACQUISITION_AUTO_SYMBOL_RATE    = 1 shl 0 ; // DVB-S Automatic Symbol Rate detection
ACQUISITION_AUTO_GUARD_INTERVAL = 1 shl 1 ; // DVB-T Automatic Guard Interval detection
ACQUISITION_AUTO_FREQ_OFFSET    = 1 shl 2 ; // DVB-T Automatic Frequency offset handling
ACQUISITION_VHF_SUPPORT         = 1 shl 3 ; // DVB-T VHF support
ACQUISITION_BANDWIDTH_6MHZ      = 1 shl 4 ; // DVB-T Support for 6MHz Bandwidth
ACQUISITION_BANDWIDTH_7MHZ      = 1 shl 5 ; // DVB-T Support for 7MHz Bandwidth
ACQUISITION_BANDWIDTH_8MHZ      = 1 shl 6 ; // DVB-T Support for 8MHz Bandwidth
ACQUISITION_DISEQC_12           = 1 shl 7 ; // DiSEqC 1.2 support
ACQUISITION_IR_INPUT_SUPPORT    = 1 shl 8 ; // IR input support

; ------------------------------------------------------------------------------

; Structure for the available device information list
ETH_LENGTH_OF_ADDRESS = 6
MAX_DEVICES_SUPPORTED = 16

; ------------------------------------------------------------------------------

TYPEDEF TB2C2_BusInterface, enum

DEVICE_INTERFACE_PCI     = 0
DEVICE_INTERFACE_USB_1_1 = 1

; ------------------------------------------------------------------------------

struct TB2C2_DeviceInformation
  dwDeviceID           DWORD ?
  ucMACAddress         CHAR ETH_LENGTH_OF_ADDRESS dup (?)
                       db 2 dup (?)
  eTunerModulation     TB2C2_TunerModulation ?
  eBusInterface        TB2C2_BusInterface ?
  wInUse               DWORD ?
  dwProductID          DWORD ?
  wsProductName        WCHAR 31 dup (?)
                       db 1 dup (?)
  wsProductDescription WCHAR 81 dup (?)
                       db 3 dup (?)
  wsProductRevision    WCHAR 21 dup (?)
                       db 3 dup (?)
  wsProductFrontEnd    WCHAR 61 dup (?)
                       db 3 dup (?)
ends
TYPEDEF PB2C2_DeviceInformation, POINTER

; ------------------------------------------------------------------------------

; Structure for Mac address list used by *UnicastMacAddress* functions

B2C2_SDK_MAC_ADDR_SIZE     = 6;
B2C2_SDK_MAC_ADDR_LIST_MAX = 32;

MAX_IP_STR_LEN = 16;

struct TB2C2_MacAddressList
  lCount      INT ? ; Input : Number of MAC addresses at array
                    ; Output: Number of MAC addresses set
  aabtMacAddr CHAR B2C2_SDK_MAC_ADDR_LIST_MAX*B2C2_SDK_MAC_ADDR_SIZE dup (?)
ends
TYPEDEF PB2C2_MacAddressList, POINTER

; ------------------------------------------------------------------------------

; Datagram Table ID enumeration used by SetTableId()/GetTableId()
TYPEDEF TB2C2_TableId, enum

TABLE_ID_3E   = 0x3E ; DVB Standard
TABLE_ID_3F   = 0x3F ; ATSC Standard
TABLE_ID_AUTO = 0xFF ; Automatic

; ------------------------------------------------------------------------------

; Definitions for scrambling control key functions
B2C2_SDK_FIXED_KEY_SIZE = 8;

; ------------------------------------------------------------------------------

TYPEDEF TB2C2_KeyTypeTAG, enum

; PID-TSC Keys           ; // up to 7 Keys possible; highest priority
B2C2_KEY_PID_TSC_01  = 1 ; //  Key is used if the PID matches and the TSC bits are '01' (reserved).
B2C2_KEY_PID_TSC_10  = 2 ; //  Key is used if the PID matches and the TSC bits are '10' (even).
B2C2_KEY_PID_TSC_11  = 3 ; //  Key is used if the PID matches and the TSC bits are '11' (odd).
; PID-only Key           ; // 1 key only; if no Global Key is set
B2C2_KEY_PID_TSC_ANY = 4 ; //  Key is used if no B2C2_KEY_PID_TSC_XX key matches and the PID value matches.
; Global Key             ; // 1 key only; if no PID-only Key is set
B2C2_KEY_GLOBAL      = 5 ; //  Key is used if no B2C2_KEY_PID_TSC_XX key matches.

; ------------------------------------------------------------------------------

; Error codes, returned by B2C2 SDK functions in addition to
; COM error codes.
B2C2_SDK_E_ALREADY_EXIST           = 0x10011000 ; // The PID to add by AddPIDsToPin or AddPIDs already exists.
; B2C2_SDK_E_PID_ERROR               = 0x90011001 ;
B2C2_SDK_E_ALREADY_FULL            = 0x90011002 ; //Failed to add PID by AddPIDsToPin or AddPIDs because maximum number reached.

; B2C2MPEG2Adapter error codes

B2C2_SDK_E_CREATE_INTERFACE        = 0x90020001 ; // Not all interfaces could be created correctly.
B2C2_SDK_E_UNSUPPORTED_DEVICE      = 0x90020002 ; // (Linux) The given network device is no B2C2 Boradband device.

B2C2_SDK_E_NOT_INITIALIZED         = 0x90020003 ; // Device has not been initialized before calling this functions.
                                                ; // Call Initialize () first.

B2C2_SDK_E_INVALID_PIN             = 0x90020004 ; // (Windows) The pin number given at the first argument is invalid { 0 ... 3 }.
B2C2_SDK_E_NO_TS_FILTER            = 0x90020005 ; // (Windows) No custom renderer filter created. Call CreateTsFilter () first.
B2C2_SDK_E_PIN_ALREADY_CONNECTED   = 0x90020007 ; // (Windows) The output pin is already connected to a renderer filter input pin.
B2C2_SDK_E_NO_INPUT_PIN            = 0x90020008 ; // (Windows) No input pin on the custom renderer filter found, check pin name if given.
B2C2_SDK_E_INVALID_TID             = 0x90020009 ; // Invalid Table ID value was used at SetTableId call

B2C2_SDK_E_SET_GLOBAL_FIXED_KEY    = 0x9002000A ; //
B2C2_SDK_E_SET_PID_FIXED_KEY       = 0x9002000B ; //
B2C2_SDK_E_GET_PID_FIXED_KEYS      = 0x9002000C ; //
B2C2_SDK_E_DELETE_PID_FIXED_KEY    = 0x9002000D ; //
B2C2_SDK_E_PURGE_FIXED_KEY         = 0x9002000E ; //

B2C2_SDK_E_DISEQC_IN_PROGRESS      = 0x9002000F ; //
B2C2_SDK_E_DISEQC_12_NOT_SUPPORTED = 0x90020010 ; //

B2C2_SDK_E_NO_DEVICE_AVAILABLE     = 0x90020011 ; //

; ------------------------------------------------------------------------------

TYPEDEF TB2C2_SpecialPids, enum

PID_CAPTURE_ALL_INCLUDING_NULLS = 0x2000
PID_CAPTURE_ALL_EXCLUDING_NULLS = 0x2001

; ------------------------------------------------------------------------------
